@@ -3,7 +3,7 @@ import socket
 import pickle
 import threading
 import traceback
-from omnitools import encryptedsocket_function, p
+from omnitools import encryptedsocket_function, p, dt2yyyymmddhhmmss
 
 
 __ALL__ = ["SS"]
@@ -22,9 +22,9 @@ class SS(object):
         self.functions = functions or {}
 
     def handler(self, conn: socket.socket, addr: tuple) -> None:
-        uid = addr[0]+":"+str(addr[1])
+        uid = "{}:{}".format(*addr)
         if not self.silent:
-            p("connected\t{uid}".format(uid=uid))
+            p("{}\tconnected\t{}".format(dt2yyyymmddhhmmss(), uid))
         try:
             while True:
                 len_response = conn.recv(4)
@@ -60,7 +60,7 @@ class SS(object):
         finally:
             conn.close()
             if not self.silent:
-                p("disconnected\t{uid}".format(uid=uid))
+                p("{}\tdisconnected\t{}".format(dt2yyyymmddhhmmss(), uid))
 
     def start(self) -> None:
         try:
